@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Moo;
 use strictures 2;
@@ -59,13 +59,13 @@ sub _build__mrd {
 }
 
 
-has pool_code => (
+has pool_select => (
     is      => 'rw',
     builder => 1,
     lazy    => 1,
 );
 
-sub _build_pool_code {
+sub _build_pool_select {
     my ($self) = @_;
     return sub { return $self->_mrd->rand };
 };
@@ -100,7 +100,7 @@ sub motif {
     my $sum = 0;
 
     while ( $sum < $self->size ) {
-        my $name = $self->pool_code->();
+        my $name = $self->pool_select->();
         my $size = $self->_duration($name);
         my $diff = $self->size - $sum;
 
@@ -151,7 +151,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -165,7 +165,7 @@ version 0.0501
     weights => [ 0.2, 0.3, 0.5 ],
   );
 
-  $mdp->pool_code( sub { ... } ); # Optional
+  $mdp->pool_select( sub { ... } ); # Optional
 
   my $motif = $mdp->motif;
 
@@ -221,10 +221,10 @@ This can be B<either> a list of duration names, as in the default
 example, or duration values, specified with a preceding 'd'.  A
 mixture of both is not well defined. YMMV
 
-=head2 pool_code
+=head2 pool_select
 
-  $code = $mdp->pool_code->();
-  $mdp->pool_code( sub { ... } );
+  $code = $mdp->pool_select->();
+  $mdp->pool_select( sub { ... } );
 
 A code reference used to select an item from the given duration
 B<pool>.
@@ -262,7 +262,7 @@ Generate a rhythmic phrase of the given B<size>.
 This method returns a possibly different rhythmic motif each time it
 is called.
 
-The default B<pool_code> used constructs this by selecting a B<pool>
+The default B<pool_select> used constructs this by selecting a B<pool>
 duration at random, that fits into the size remaining after each
 application, in a loop until the B<size> is met.
 
